@@ -216,11 +216,19 @@ def plot_image (app, plot):
 
         args.append(infullfn)
     elif args[0] == "convert":
-        # Attach the body and change the embeded output file.
+        # The body is a shell script, meanwhile replace the last para as
+        # output filename
+        tmp = []
         if text:
             for i in StringIO(text).readlines():
-                args.extend(shlex.split(i.rstrip("\r\n\\")))
-        args[-1] = out["outfullfn"]
+                tmp.extend(i.rstrip("\r\n\\").split())
+
+        if "convert" not in tmp[0]:
+            tmp.insert(0, "convert")
+        tmp[-1] = out["outfullfn"]
+        text = " ".join(tmp)
+        #print("text: %s" %(text))
+        args = ["sh", infullfn]
     else:
         args.append(infullfn)
 
@@ -291,7 +299,9 @@ def cmd_2_image (app, plot):
         format_map.update(app.builder.config.plot_output_format)
         plot_format = format_map.get(app.builder.format, "png")
     # convert only support png.
-    plot_format = options.get("convert", None) and "png" or plot_format
+    if "convert" in cmd or options.get("convert", None):
+        # convert is based on pixel and don't use the svg/pdf
+        plot_format = "png"
     options["plot_format"] = plot_format
 
     hashkey = cmd + str(options) + text
@@ -308,7 +318,7 @@ def cmd_2_image (app, plot):
 
     if options.get("show_source", False):
         out["outreference"] = posixpath.join(rel_imgpath, infname)
-    if (options.get("name", None) and app.builder.format in ["html"]):
+    if options.get("name", None):
         #Rename the output to options["name"] only in html
         outfname = '%s.%s' %(options["name"], plot_format)
         out2 = dict(outrelfn = posixpath.join(rel_imgpath, outfname),
@@ -317,7 +327,7 @@ def cmd_2_image (app, plot):
         shutil.copy(out["outfullfn"], out2["outfullfn"])
         print("copy %s -> %s" %(os.path.basename(out["outfullfn"]),
             os.path.basename(out2["outfullfn"])))
-        out = out2
+        out = (app.builder.format in ["html"]) and out2 or out
     return out
 
 def setup(app):
